******************************************************************************
*
*  PRTCHK DEMO
*
*  Written by Jackie Ammerman
*             Ammerman Information Management Systems
*             129 West Davis Street
*             Decatur, GA 30030
*             404-377-0207
*
*   I discovered when doing some error trapping on a Clipper application
*   that the ISPRINTER() function in clipper.lib only checks LPT1.  I wanted
*   to be able to check LPT2 and LPT3 as well.
*
*   This program demonstrates a simple C function which will check the
*   status of the parallel port passed to it.  Based upon the numeric value
*   which is returned, a message can be displayed indicating the printer
*   status.
*
*   In order to use the function, the pchk.obj file must be linked in.
*
*   Example:  tlink prt pchk,,,clipper extend
*
*   This  function is placed in the public domain.
*   If you like it, use it.
*****************************************************************************

clear

* Define values to pass to the c function for each of the parallel ports
prt1=0    && LPT1
prt2=1    && LPT2
prt3=2    && LPT3

* Initialize the variables which will receive the printer status
result1=0
result2=0
result3=0

* Call the PRTCHK function
* The parallel port to check is passed to the function
result1=prtchk(prt1)
result2=prtchk(prt2)
result3=prtchk(prt3)

* Display the printer status for the three ports
* The stat_str() function is called which converts the numeric
* value of the printer status to a string message

@ 15,20 say "LPT1: = " +stat_str(result1)
@ 16,20 say "LPT2: = " +stat_str(result2)
@ 17,20 say "LPT3: = " +stat_str(result3)
quit



func stat_str
param num
* Convert the printer status value to a string
if num = 2
  s = "No Printer              "
elseif num = 8
  s = "Printer is OFF-LINE     "
elseif num = 40
  s = "No Paper...             "
elseif num = 144
  s = "READY                   "
elseif num = 200
  s = "Printer is turned off   "
else
  s = "Undefined Printer Error "
end
return(s)
